=== modified file 'UpdateManager/Dialogs.py'
--- UpdateManager/Dialogs.py	2018-02-09 12:48:59 +0000
+++ UpdateManager/Dialogs.py	2018-08-20 11:03:31 +0000
@@ -26,6 +26,7 @@
 gi.require_version("Gtk", "3.0")
 from gi.repository import Gtk
 from gi.repository import Gdk
+from gi.repository import Gio
 import warnings
 warnings.filterwarnings(
     "ignore", "Accessed deprecated property", DeprecationWarning)
@@ -33,11 +34,13 @@
 import logging
 import datetime
 import dbus
+import distro_info
 import os
 import subprocess
 
 import HweSupportStatus.consts
 from .Core.LivePatchSocket import LivePatchSocket
+from .Core.utils import get_dist
 
 from gettext import gettext as _
 from gettext import ngettext
@@ -97,6 +100,8 @@
         ui_path = os.path.join(window_main.datadir, "gtkbuilder/Dialog.ui")
         BuilderDialog.__init__(self, window_main, ui_path, "pane_dialog")
 
+        self.settings = Gio.Settings.new("com.ubuntu.update-manager")
+
         self.focus_button = None
         self.set_content_widget(content_widget)
         self.connect("realize", self._on_realize)
@@ -144,10 +149,20 @@
             self.main_container.add(content_widget)
         self.main_container.set_visible(bool(content_widget))
 
+    def _is_livepatch_supported(self):
+        di = distro_info.UbuntuDistroInfo()
+        codename = get_dist()
+        return di.is_lts(codename)
+
     def on_livepatch_status_ready(self, active, cs, ps, fixes):
         self.set_desc(None)
 
         if not active:
+            if self._is_livepatch_supported() and \
+               self.settings.get_int('launch-count') >= 4:
+                self.set_desc (_("<b>Tip:</b> You can use Livepatch to keep your "
+                                 "computer more secure between restarts."))
+                self.settings_button.set_label(_("Settings & Livepatch…"))
             return
 
         needs_reschedule = False
@@ -208,7 +223,7 @@
             self.set_header(_("No software updates are available."))
         else:
             self.set_header(_("The software on this computer is up to date."))
-        self.add_settings_button()
+        self.settings_button = self.add_settings_button()
         self.focus_button = self.add_button(Gtk.STOCK_OK,
                                             self.window_main.close)
         self.check_livepatch_status()

=== modified file 'data/com.ubuntu.update-manager.gschema.xml.in'
--- data/com.ubuntu.update-manager.gschema.xml.in	2017-03-14 20:46:06 +0000
+++ data/com.ubuntu.update-manager.gschema.xml.in	2018-08-20 11:03:31 +0000
@@ -50,5 +50,10 @@
       <summary>Time when update-manager got launched last</summary>
       <description>The last time update-manager was run.</description>
     </key>
+    <key name="launch-count" type="i">
+      <default>0</default>
+      <summary>Number of times update-manager has been launched</summary>
+      <description>Number of times update-manager has been launched.</description>
+    </key>
   </schema>
 </schemalist>

=== modified file 'debian/changelog'
--- debian/changelog	2018-06-27 12:16:47 +0000
+++ debian/changelog	2018-08-20 11:03:31 +0000
@@ -1,3 +1,9 @@
+update-manager (1:18.10.4) UNRELEASED; urgency=medium
+
+  * Add a reminder to enable Livepatch (LP: #1787553).
+
+ -- Andrea Azzarone <andrea.azzarone@canonical.com>  Mon, 20 Aug 2018 13:59:48 +0300
+
 update-manager (1:18.10.3) cosmic; urgency=medium
 
   * Add support for HTTPS proxies; this breaks UpdateManager.Core.utils.init_proxy()

=== modified file 'update-manager'
--- update-manager	2017-07-12 22:03:00 +0000
+++ update-manager	2018-08-20 11:03:31 +0000
@@ -111,6 +111,7 @@
   # keep track when we run (for update-notifier)
   settings =  Gio.Settings.new("com.ubuntu.update-manager")
   settings.set_int64("launch-time", int(time.time()))
+  settings.set_int("launch-count", settings.get_int("launch-count") + 1)
   init_proxy(settings)
 
   app = UpdateManager(data_dir, options)

